@@ -1,6 +1,6 @@
 /*
  * twlog:  A basic ham loging program using Motif
- * Copyright (C) 1997->2006 Ted Williams WA0EIR 
+ * Copyright (C) 1997->2007 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.4 -  Oct 2006
+ * Version: 2.5 -  Dec 2007
  */
 
 /*
@@ -29,8 +29,12 @@
 
 #include "twlog.h"
 
-#ifdef MAKE_ICON
-#include "icons/twlog.xpm"
+#if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM
+   #include <X11/xpm.h>
+   #include "icons/twlog.xpm"
+   Pixmap pixmap, mask;
+   XpmAttributes pix_attributes;
+   XpmColorSymbol transparentColor[1] = { {NULL, "none", 0} };
 #endif
 
 int shmid;
@@ -40,17 +44,8 @@ int main (int argc, char *argv[])
 {
    XtAppContext ac;
    LogRes log_res;
-//TJW   struct stat buf;
    Dimension h = 0, w = 0;
 
-#ifdef MAKE_ICON
-//   Widget iconwin;
-   Pixmap pixmap, mask;
-   XpmAttributes pix_attributes;
-   XpmColorSymbol transparentColor[1] = { {NULL, "none", 0} };
-//   Pixel bg;
-#endif
-
    /*
     * Describe the application defined resources. This struct is
     * for the app resources which are read in the resource
@@ -59,70 +54,71 @@ int main (int argc, char *argv[])
    XtResource app_res_desc[] = 
    {
       {
-         XmNtzone,           /* Name */
-         XmCTzone,           /* Class */
-         XmRInt,             /* Target data type */
-         sizeof (int),       /* Size of target type */
+         XmNtzone,                   /* Name */
+         XmCTzone,                   /* Class */
+         XmRInt,                     /* Target data type */
+         sizeof (int),               /* Size of target type */
          XtOffsetOf (LogRes, tzone), /* Offset into LogRes */
-         XtRImmediate,       /* Default data type */
-         (XtPointer) 2       /* This will force an error if not found */
+         XtRImmediate,               /* Default data type */
+         (XtPointer) 1               /* Default value */
       },
 
       {
-         XmNbands,           /* Same a above */
+         XmNbands,                   /* Same a above */
          XmCBands,
-         XmRXmStringTable,
-         sizeof (XmStringTable),
+         XmRStringTable,
+         sizeof (String *),
          XtOffsetOf (LogRes, bands),
-         XtRString,
-         "Not Found"         /* Default to "Not Found" */
+         XmRString,
+         "-1"                        /* Defaults to "-1" if Twlog not found */
       },
 
       {
-         XmNdefault_band,    /* Same a above */
+         XmNdefault_band,            /* Same a above */
          XmCDefault_band,
          XmRInt,
          sizeof (int),
          XtOffsetOf (LogRes, default_band),
-         XtRImmediate, 0     /* Default to first button */
+         XtRImmediate,
+         0
       },
 
       {
-         XmNmodes,           /* Same a above */
+         XmNmodes,                   /* Same a above */
          XmCModes,
-         XmRXmStringTable,
-         sizeof (XmStringTable),
+         XmRStringTable,
+         sizeof (String *),
          XtOffsetOf (LogRes, modes),
-         XtRString,
-         "Not Found"         /* Default to "Not Found" */
+         XmRString,
+         "1"
       },
 
       {
-         XmNdefault_mode,    /* Same a above */
+         XmNdefault_mode,            /* Same a above */
          XmCDefault_mode,
          XmRInt,
          sizeof (int),
          XtOffsetOf (LogRes, default_mode),
-         XtRImmediate, 0     /* Default to first button */
+         XtRImmediate, 0             /* Default to first button */
       },
 
       {
-         XmNpower,           /* Same a above */
+         XmNpower,                   /* Same a above */
          XmCPower,
-         XmRXmStringTable,
-         sizeof (XmStringTable),
+         XmRStringTable,
+         sizeof (String *),
          XtOffsetOf (LogRes, power),
-         XtRString,
-         "Not Found"         /* Default to "Not Found" */
+         XmRString,
+         "1"
       },
 
       {
-         XmNdefault_power,   /* Same a above */
+         XmNdefault_power,           /* Same a above */
          XmCDefault_power,
          XmRInt,
          sizeof (int),
          XtOffsetOf (LogRes, default_power),
-         XtRImmediate, 0     /* Default to first button */
+         XtRImmediate, 0             /* Default to first button */
       }
    };
 
@@ -139,28 +135,12 @@ int main (int argc, char *argv[])
    logSH = XtVaAppInitialize (&ac, "Twlog", NULL, 0, &argc, argv, NULL,
       XmNmwmFunctions, MWM_FUNC_ALL | MWM_FUNC_CLOSE,
       XmNtitle, "TWLOG",
-      /* XmNiconName, "TWLOG", */
       NULL);
 
-   XtGetApplicationResources (logSH, &log_res, app_res_desc,
-      XtNumber (app_res_desc), NULL, 0);
-
-#ifdef MAKE_ICON
+#if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM
    /*
-    * If MAKE_ICON is defined, create pixmap for application Icon
+    *  then create pixmap for application Icon
     */
-//   iconwin = XtVaAppCreateShell ("Iconwin", "logSH",
-//      wmShellWidgetClass, XtDisplay (logSH),
-//      XmNmappedWhenManaged, False,
-//      XmNwidth,  60,
-//      XmNheight, 40,
-//      NULL);
-
-//   XtVaGetValues (iconwin,
-//      XmNbackground, &bg,
-//      NULL);
-
-//   transparentColor[0].pixel = bg;
    pix_attributes.closeness = 40000;
    pix_attributes.valuemask = XpmColorSymbols | XpmCloseness;
    pix_attributes.colorsymbols = transparentColor;
@@ -169,41 +149,38 @@ int main (int argc, char *argv[])
    XpmCreatePixmapFromData (XtDisplay (logSH),
       DefaultRootWindow (XtDisplay (logSH)),
       twlog_xpm, &pixmap, &mask, &pix_attributes);
+
+   XtVaSetValues (logSH,
+      XmNiconPixmap, pixmap,
+      NULL);
 #endif
 
+   XtGetApplicationResources (logSH, &log_res, app_res_desc,
+      XtNumber (app_res_desc), NULL, 0);
+
+   /*
+    * Check bands for "-1". If so, realize the shell, call error dialog,
+    * and allow diag to force exit since the resource file was not found.
+    */
+   if (strcmp (log_res.bands[0], "-1") == 0)
+   {
+      XtRealizeWidget (logSH);
+      errorDiag (logSH, "The resource file, Twlog, is missing.\n"
+                        "This is an installation problem.  Did\n"
+                        "you install twlog as root?\n"
+                        "twcw must exit.\n\n"
+                        "Please send bug reports to\n" PACKAGE_BUGREPORT,
+                         CANCEL_BTN);
+      fprintf (stderr, "twlog: The resource file, Twlog, is missing.\n");
+      XtAppMainLoop (ac);
+   }
+
+
    /*
     * Build the widgets
     */
    build_widgets (logSH, log_res);
 
-#if 0    //This goes away - See initCB in twlogCB.c
-   /*
-    * Initialize dirpath and logpath.
-    * Then, check that the path is valid.
-    */
-   if (stat (getenv ("HOME"), &buf) == -1)      /* Do you have a $HOME? */
-   {
-      fprintf (stderr, "twlog: Can't find your \"$HOME\"\n");
-      exit (1);
-   }
-
-   strcpy (dirpath, getenv ("HOME"));   /* $HOME to dir path */
-   strcat (dirpath, LOGDIR);            /* then add LOGDIR   */
-   if (stat (dirpath, &buf) == -1)      /* does $HOME/LOGDIR exist? */
-   {
-      fprintf (stderr, "twlog: Can't find log directory %s\n", dirpath);
-      exit (1);
-   }
-
-   strcpy (logpath, dirpath);           /* dirpath to logpath */
-   strcat (logpath, LOGFILE);           /* add LOGFILE name   */
-   if (stat (logpath, &buf) == -1)      /* and check that it exists */
-   {
-      fprintf (stderr, "twlog: Can't find %s\n", logpath);
-      exit (1);
-   }
-#endif
-
    /*
     * Initialize the Timezone
     * Check the timezone resource and do a tzset if OK.  If the value
@@ -227,44 +204,6 @@ int main (int argc, char *argv[])
    }
    tzset ();
 
-   /*
-    * Realize the widgets and set pixmap properties for logSH
-    * and iconwin
-    */
-   XtRealizeWidget (logSH);
-
-#ifdef MAKE_ICON
-//   XtRealizeWidget (iconwin);
-   /*
-    * Set pixmap properties in clock_shell and iconwin
-    */
-//   XtVaSetValues (iconwin,
-//      XmNbackgroundPixmap, pixmap,
-//      NULL);
-
-//   XtVaSetValues (logSH,
-//      XmNiconWindow, XtWindow (iconwin),
-//      NULL);
-#endif
-
-   /*
-    * Set max and min height to current height.  Set min width to 
-    * current width.  Then, go into loop mode.
-    */
-   XtVaGetValues (logSH,
-      XmNheight, &h,
-      XmNwidth, &w,
-      NULL);
-
-   XtVaSetValues (logSH,
-      XmNminHeight, h, 
-      XmNmaxHeight, h,
-      XmNminWidth, w,
-#ifdef MAKE_ICON
-      XmNiconPixmap, pixmap,
-#endif
-      NULL);
-
    /*
     * get shared memory segment and attach it
     */
@@ -280,6 +219,30 @@ int main (int argc, char *argv[])
       exit (1);
    }
 
+   /*
+    * Realize the widgets
+    */
+   XtRealizeWidget (logSH);
+
+   /*
+    * Set max and min height to current height.  Set min width to 
+    * current width.  Then, go into loop mode.
+    */
+   XtVaGetValues (logSH,
+      XmNheight, &h,
+      XmNwidth, &w,
+      NULL);
+
+   XtVaSetValues (logSH,
+      XmNminHeight, h, 
+      XmNmaxHeight, h,
+      XmNminWidth, w,
+      NULL);
+
+   /*
+    * Realize the widgets and enter the main loop
+    */
+   XtRealizeWidget (logSH);
    XtAppMainLoop (ac);
    return 0;                    /* Never get here */
 }
