@@ -9,11 +9,7 @@
 #ifndef TWLOG_H_INCLUDED
 #define TWLOG_H_INCLUDED
 
-#define MAKE_ICON
-#ifdef MAKE_ICON 
-#include <X11/xpm.h>
-#endif
-
+#include "../config.h"
 #include <time.h>
 #include <errno.h>
 #include <stdio.h>
@@ -41,19 +37,20 @@
 #include <Xm/Separator.h>
 #include <Xm/SelectioB.h>
 
+#define MAKE_ICON 1
 
 #define XS_CONVERT( property, value ) \
            XtVaTypedArg, (property), XmRString, (value), strlen(value) + 1
 
-#define KEY      6146            /* Some nice number */
-#define SHMSIZE  40              /* Size of shared memory */ 
-#define NO_CANCEL  1
+#define KEY        6146            /* Some nice number */
+#define SHMSIZE    40              /* Size of shared memory */ 
+#define CANCEL_BTN 1
 #define MAXNAME    25
 #define PBWIDTH    80
 #define MARGIN     20
-#define LOGDIR    "/.twlogDir"  /* needed to build dirpath and logpath */
-#define LOGFILE   "/logfile"
-#define PRINT_CMD "lpr "         /* needs the space after the command */
+#define LOGDIR     "/.twlogDir"    /* needed to build dirpath and logpath */
+#define LOGFILE    "/logfile"
+#define PRINT_CMD  "lpr "          /* needs the space after the command */
 
 /*
  * APPLICATION DEFINED RESOURCES 
@@ -78,13 +75,13 @@
 
 typedef struct
 {
-   int tzone;
-   XmStringTable bands;
-   int default_band;
-   XmStringTable modes;
-   int default_mode;
-   XmStringTable power;
-   int default_power;
+   int    tzone;
+   char **bands;
+   int    default_band;
+   char **modes;
+   int    default_mode;
+   char **power;
+   int    default_power;
 } LogRes;
 
 typedef struct
@@ -106,7 +103,7 @@ char logpath[100];
  * FUNCTION DECLARATIONS
  */
 void build_widgets (Widget w, LogRes app_data);
-Widget buildOptionMenus (Widget parent, int defaultBtn, XmString * labelXS);
+Widget buildOptionMenus (Widget parent, int defaultBtn, String *labelXS);
 void dateCB (Widget w, XtPointer cdata, XtPointer cbs);
 void startCB (Widget w, XtPointer cdata, XtPointer cbs);
 void callsignCB (Widget w, XtPointer cdata, XtPointer cbs);
@@ -128,10 +125,13 @@ void cellCB (Widget w, XtPointer cdata, XtPointer cbs);
 void popupFindCB (Widget w, XtPointer cdata, XtPointer cbs);
 void doFindCB (Widget w, XtPointer cdata, XtPointer cbs);
 void browserCB (Widget w, XtPointer cdata, XtPointer cbs);
-void errOkCB (Widget w, XtPointer cdata, XtPointer cbs);
 void noMatchDiag (void);
 void mk_log (void);
-void errorDiag (Widget w, char *emess, int no_cancel);
+void errorDiag (Widget w, char *emess, int cancel);
+void errOkCB (Widget w, XtPointer cdata, XtPointer cbs);
+void errCancelCB (Widget w, XtPointer cdata, XtPointer cbs);
+void confirmDiag (Widget w);
+void confOkCB (Widget w, XtPointer cdata, XtPointer cbs);
 char *findNoCase (char *text, char *pattern);
 void promptCB (Widget w, XtPointer cdata, XtPointer cbs);
 void popdownCB (Widget w, XtPointer cdata, XtPointer cbs);
