@@ -1,6 +1,6 @@
 /*
  * twlog:  A basic ham loging program using Motif
- * Copyright (C) 1997->2006 Ted Williams WA0EIR 
+ * Copyright (C) 1997->2007 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.4 -  Oct 2006
+ * Version: 2.5 -  Dec 2007
  */
 
 /*
@@ -42,6 +42,7 @@
 
 extern int shmid;          /* IPC ID for shared memory */
 extern void *shareCall;    /* Shared memory ptr - call of current station */
+extern Pixmap pixmap;      /* pixmap for the application icon */
 
 /*
  * dateCB Callback
@@ -135,7 +136,6 @@ void callsignCB (Widget w, XtPointer cdata, XtPointer cbstruct)
 
          /* create popup and search for His call to see if we have */
          /* worked him before */
-         /* TJW - causes problem opening logfile if permission are funky */
          if (mwText == NULL)
          {
             build_editor ();
@@ -522,7 +522,7 @@ void initCB (Widget w, XtPointer cdata, XtPointer cbs)
            "Twlog needs to create .twlogDir/logfile in your home directory.\n"
            "Click OK to create it or Cancel to exit.\n";
 
-   /* remove this callback so it is only called at start up */
+   /* remove this callback so it is only called once at start up */
    XtRemoveCallback (w, XmNfocusCallback, initCB, NULL);
 
    if (stat (getenv ("HOME"), &buf) == -1)      /* Do you have a $HOME? */
@@ -559,9 +559,16 @@ void initCB (Widget w, XtPointer cdata, XtPointer cbs)
    if (eflag > 0)
    {
       /* create and popup the dialog */
-      //TJW use below - via Jacob KD7YKO xs = XmStringCreateLocalized (mess);
+      /* use below - via Jacob KD7YKO xs = XmStringCreateLocalized (mess); */
       xs = XmStringCreateLtoR (mess, XmSTRING_DEFAULT_CHARSET);
-      initDiag = XmCreateQuestionDialog (logSH, "Create Files", NULL, 0);
+      initDiag = XmCreateQuestionDialog (logSH, "initDiag", NULL, 0);
+
+      XtVaSetValues (XtParent (initDiag),
+         XmNtitle, "CREATE LOGFILE",
+         #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM
+         XmNiconPixmap, pixmap,
+         #endif
+         NULL);
 
       XtVaSetValues (initDiag,
          XmNdialogStyle, XmDIALOG_PRIMARY_APPLICATION_MODAL,
@@ -602,11 +609,9 @@ void initDiagCB (Widget w, XtPointer cdata, XtPointer cbs)
          switch (eflag)
          {
             case 2:
-               printf ("case 2 - make dir %s\n", dirpath);
                mkdir (dirpath, modeDir);
                /* No break - we need to fall through */
             case 1:
-               printf ("case 1 - make file %s\n", logpath);
                creat (logpath, modeLog);
                break;
             default:
