@@ -1,6 +1,6 @@
 /*
  * twlog:  A basic ham loging program using Motif
- * Copyright (C) 1997->2006 Ted Williams - WA0EIR 
+ * Copyright (C) 1997->2007 Ted Williams - WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.4 -  Oct 2006
+ * Version: 2.5 -  Dec 2007
  */
 
 /*
@@ -25,11 +25,16 @@
  */
 
 #include "twlog.h"
+
                                 /* from the top down, list QSOs */
-#define FORWARD 0               /* recent to oldest QSO or */
-#define REVERSE 1               /* oldest to recent QSO */
+#define FORWARD   0             /* recent to oldest QSO or */
+#define REVERSE   !FORWARD      /* oldest to recent QSO */
 #define DIRECTION FORWARD
 
+extern int shmid;
+#if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+extern Pixmap pixmap;
+#endif
 
 struct tag2
 {
@@ -77,6 +82,9 @@ Widget build_editor ()
       editDiag =
          XtVaCreateWidget ("editDiag", xmDialogShellWidgetClass, logSH,
          XmNtitle, "TWLOG EDITOR",
+         #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+         XmNiconPixmap, pixmap,
+         #endif
          XmNmwmDecorations,
             MWM_DECOR_RESIZEH | MWM_DECOR_TITLE | MWM_DECOR_BORDER,
          NULL);
@@ -143,7 +151,7 @@ Widget build_editor ()
          XmNleftOffset, MARGIN,
          NULL);
 
-      mwText = XtVaCreateWidget ("mwText", xbaeMatrixWidgetClass, form2,
+      mwText = XtVaCreateManagedWidget ("mwText", xbaeMatrixWidgetClass, form2,
          XmNtopAttachment, XmATTACH_FORM,
          XmNtopOffset, MARGIN,
          XmNbottomAttachment, XmATTACH_WIDGET,
@@ -231,7 +239,7 @@ void cellCB (Widget w, XtPointer cdata, XtPointer cbs)
          mods = 0;
          break;
 
-         /* so what do we want to use these for? */
+      /* so what do we want to use these for? */
       case XbaeModifyVerifyReason:
          mods = 1;
          /* check the row we modified and make sure we don't exceed the len */
@@ -242,6 +250,7 @@ void cellCB (Widget w, XtPointer cdata, XtPointer cbs)
          pt2 = (XbaeMatrixEnterCellCallbackStruct *) cbs;
          if (pt2->column == 0)
          {
+//TJW
             // could add a delete row operation here
             // XbaeMatrixSelectRow (w, pt2->row);
             // printf ("delete qso #%s\n", XbaeMatrixGetCell (w,
@@ -269,7 +278,8 @@ void saveCB (Widget w, XtPointer cdata, XtPointer cbs)
    /* open the file */
    if ((fp = fopen (logpath, "w")) == 0)
    {
-      fprintf (stderr, "%s:  open failed\n", logpath);
+      errorDiag (w,"Open logfile for write failed.", !CANCEL_BTN);
+      fprintf (stderr, "%s:  Open logfile for write failed\n", logpath);
       return;
    }
 
@@ -422,15 +432,21 @@ void aboutDiag ()
    Widget pb;
    XmString msg_xs;
    char msg_str[] =
-      "twlog \251 1997 was written by\nTed Williams - WA\330EIR";
+      PACKAGE_STRING
+      " \251 1997-2008\nwas written by Ted Williams - WA\330EIR\n\n"
+      "Please send bug reports to\n" PACKAGE_BUGREPORT;
 
    msg_xs = XmStringCreateLtoR (msg_str, XmSTRING_DEFAULT_CHARSET);
    if (diag == NULL)
    {
-      diag =
-         XmCreateInformationDialog (logSH, "aboutDiag", (ArgList) NULL, 0);
+      diag = XmCreateInformationDialog (logSH, "aboutDiag",
+         (ArgList) NULL, 0);
+
       XtVaSetValues (XtParent (diag),
          XmNtitle, "ABOUT TWLOG",
+         #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+         XmNiconPixmap, pixmap,
+         #endif
          NULL);
 
       XtVaSetValues (diag,
@@ -451,7 +467,7 @@ void aboutDiag ()
 
 
 /*
- * numbers the rows in a matrix
+ * number the rows in a matrix
  */
 void numberRows (Widget mw)
 {
@@ -507,7 +523,9 @@ void mwLoad (Widget mw)
    /* open the file */
    if ((fp = fopen (logpath, "r")) == 0)
    {
-      fprintf (stderr, "logfile open failed\n");
+      errorDiag (XtParent(mw), "Open logfile for read failed.", !CANCEL_BTN);
+      fprintf (stderr, "open logfile for read failed\n");
+      return;
    }
 
    /* get lines */
@@ -559,7 +577,7 @@ void build_convDiag (void)
    static Widget inLabel, inBrowsePB, typeLabel;
    static Widget outLabel, outBrowsePB;
    static Widget wids[3];
-   Arg args[5];
+   Arg args[10];              /* room to spare */
    XmString xs[5];
 
    if (convDiag == NULL)      /* Lazy instantiation */
@@ -575,6 +593,9 @@ void build_convDiag (void)
       XtSetArg (args[j], XmNdialogStyle,
                          XmDIALOG_PRIMARY_APPLICATION_MODAL); j++;
       XtSetArg (args[j], XmNautoUnmanage, False); j++;
+      #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+      XtSetArg (args[j], XmNiconPixmap, pixmap); j++;
+      #endif
 
       convDiag = XmCreateTemplateDialog (logSH, "convDiag", args, j);
 
@@ -582,13 +603,11 @@ void build_convDiag (void)
       {
 	 XmStringFree (xs[j]);
       }
-//TJW
-//XtVaCreateManagedWidget ("OK", xmPushButtonWidgetClass, convDiag, NULL);
 
       form4 = XtVaCreateWidget ("convForm", xmFormWidgetClass, convDiag,
          NULL);
 
-      topLabel = XtVaCreateManagedWidget ("Convert Log Format",
+      topLabel = XtVaCreateManagedWidget ("Convert Log",
          xmLabelWidgetClass, form4,
          XmNtopAttachment, XmATTACH_FORM,
          XmNleftAttachment, XmATTACH_FORM,
@@ -668,8 +687,8 @@ void build_convDiag (void)
          XmNbottomAttachment, XmATTACH_OPPOSITE_WIDGET,
          XmNbottomWidget, typeLabel,
          XmNrightAttachment, XmATTACH_NONE,
+         XmNborderWidth, 0,
          NULL);
-         XtUnmanageChild (XmOptionLabelGadget (wids[2]));
 
       outLabel = XtVaCreateManagedWidget ("Output File:", xmLabelWidgetClass,
          form4,
@@ -715,7 +734,6 @@ void build_convDiag (void)
 
       XtAddCallback (inBrowsePB, XmNactivateCallback, browserCB, wids[0]);
       XtAddCallback (outBrowsePB, XmNactivateCallback, browserCB, wids[1]);
-//TJW change convDiag to new pb's
       XtAddCallback (convDiag, XmNokCallback, convCB, wids);
       XtAddCallback (convDiag, XmNcancelCallback, convCB, wids);
    }
@@ -736,18 +754,29 @@ void browserCB (Widget w, XtPointer cdata, XtPointer cbs)
 
    strcpy (dirStr, getenv ("HOME"));       /* build the dir string */
    strcat (dirStr, LOGDIR);
-   strcat (dirStr, LOGFILE);
+   strcat (dirStr, "/*");
    xs = XmStringCreateLocalized (dirStr);  /* build xs for fsb dir */
 
    /* create fsb for input file */
    fsb1 = XmCreateFileSelectionDialog (w, "fsb1", NULL, 0);
 
    XtVaSetValues (fsb1,
-      XmNdirectory, xs,                    /* set dir value */
+      XmNdirMask, xs,                    /* set dir value */
       XmNmustMatch, True,
       XmNdialogStyle, XmDIALOG_PRIMARY_APPLICATION_MODAL,
+      #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+      XmNiconPixmap, pixmap,
+      #endif
       NULL);
    XmStringFree (xs);
+
+   XtVaSetValues (XtParent(fsb1),
+      XmNtitle, "TWLOG FILE BROWSER",
+      #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+      XmNiconPixmap, pixmap,
+      #endif
+      NULL);
+
    XtUnmanageChild (XmFileSelectionBoxGetChild (fsb1, XmDIALOG_HELP_BUTTON));
 
    /* add some callbacks */
@@ -788,11 +817,11 @@ void fsbCB (Widget w, XtPointer cdata, XtPointer cbs)
          break;
 
       case XmCR_NO_MATCH:
-         errorDiag (w, "You need to select a file.", NO_CANCEL);
+         errorDiag (w, "You need to select a file.", !CANCEL_BTN);
          return;
 
       default:
-         printf ("fsbCB: invalid request\n");
+         fprintf (stderr, "fsbCB: invalid request\n");
          break;
    }
    XtUnmanageChild ((Widget) w);
@@ -838,21 +867,21 @@ void convCB (Widget w, XtPointer cdata, XtPointer cbs)
    /***** Input path *****/
    if ((rtn = stat (infile, &buf)) == -1)          /* stat input file */
    {
-      //fprintf (stderr, "The Input file was not found\n");
-      errorDiag (w, "The Input file was not found\n", NO_CANCEL);
+      errorDiag (w, "The Input file was not found.\n", !CANCEL_BTN);
+      fprintf (stderr, "Input file was not found\n");
       return;
    }
    if (S_ISDIR(buf.st_mode) == 1)                  /* can't be a dir */
    {
-      //fprintf (stderr, "The Input file can't be a directory.\n");
-      errorDiag (w, "The Input file can not be a directory.", NO_CANCEL);
+      errorDiag (w, "The Input file can not be a directory.", !CANCEL_BTN);
+      fprintf (stderr, "Input file can't be a directory\n");
       return;
    }
    if ((S_IRUSR & buf.st_mode) == 0) 
    {
-      //fprintf (stderr, "You do not have read premission\n");
-      errorDiag (w, "You do not have read permission on the Input file\n",
-                 NO_CANCEL);
+      errorDiag (w, "You do not have read permission on the Input file.\n",
+                 !CANCEL_BTN);
+      fprintf (stderr, "You do not have read premission\n");
       return;
    }
 
@@ -860,21 +889,21 @@ void convCB (Widget w, XtPointer cdata, XtPointer cbs)
    rtn = stat (outfile, &buf);
    if ((rtn == 0) && (S_ISDIR(buf.st_mode) == 1))  /* can't be a dir */
    {
-      //fprintf (stderr, "The Output file can't be a directory.\n");
-      errorDiag (w, "The Output file can not be a directory.", NO_CANCEL);
+      errorDiag (w, "The Output file can not be a directory.", !CANCEL_BTN);
+      fprintf (stderr, "Output file can't be a directory.\n");
       return;
    }
    if (strcmp (infile, outfile) == 0)              /* names can't be == */
    {
-      //fprintf (stderr, "Input and Output fills can not be the same.\n");
-      errorDiag (w, "Input and Output files can not be the same.", NO_CANCEL);
+      errorDiag (w, "Input and Output files can not be the same.", !CANCEL_BTN);
+      fprintf (stderr, "Input and Output fills can not be the same.\n");
       return;
    }
    if ((rtn == 0) && ((S_IWUSR & buf.st_mode) == 0)) /* exists but no write*/
    {
-      //printf ("You do not have write permission on the Output File\n");
       errorDiag (w, "You do not have write permission on the Output File.",
-                 NO_CANCEL);
+                 !CANCEL_BTN);
+      fprintf (stderr, "You do not have write permission on the Output File\n");
       return;
    }
 
@@ -889,10 +918,9 @@ void convCB (Widget w, XtPointer cdata, XtPointer cbs)
    /* this must be the last check */
    /* check for exists and writable here */
    if ((rtn == 0) && S_ISREG(buf.st_mode) == 1)  /* if file exists */
-   {
-      //printf ("The Output file exists. Do you want to overwrite it?\n");
-      errorDiag (w, "The Output file exists. Do you want to overwrite it?",
-                      !NO_CANCEL);
+   {            //w or do we want the shell? 
+      confirmDiag (w);
+      fprintf (stderr, "The Output file exists.");
       return;
    }
 
@@ -903,6 +931,58 @@ void convCB (Widget w, XtPointer cdata, XtPointer cbs)
 }
 
 
+/*
+ * confirmDiag
+ */
+void confirmDiag (Widget w)
+{
+   Widget confDiag;
+   XmString xs_mess, xs_yes, xs_no;
+
+   confDiag = XmCreateErrorDialog (w, "confDiag", NULL, 0);
+   xs_mess = XmStringCreateLocalized ("The ouput file exists.\n"
+                                      "Do you want to overwrite it?");
+   xs_yes = XmStringCreateLocalized("Yes");
+   xs_no = XmStringCreateLocalized("No");
+
+   XtVaSetValues (XtParent(confDiag),
+      XmNtitle, "CONVERT DIALOG",
+      XmNmwmFunctions, MWM_FUNC_ALL | MWM_FUNC_CLOSE,
+      NULL);
+
+   XtVaSetValues (confDiag,
+      XmNdialogStyle, XmDIALOG_PRIMARY_APPLICATION_MODAL,
+      XmNmessageString, xs_mess,
+      XmNcancelLabelString, xs_no,
+      XmNokLabelString, xs_yes,
+      NULL);
+   XmStringFree (xs_yes);
+   XmStringFree (xs_no);
+
+   XtUnmanageChild (XmMessageBoxGetChild(confDiag, XmDIALOG_HELP_BUTTON));
+
+   XtAddCallback (confDiag, XmNokCallback, confOkCB, (XtPointer) w);
+//   XtAddCallback (confDiag, XmNcancelCallback, confCancelCB, w);
+
+   XtManageChild (confDiag);
+}
+
+
+/*
+ * confOkCB - OK callback for confDiag - OK to overwrite the existing
+ * output file
+ */
+void confOkCB (Widget w, XtPointer cdata, XtPointer cbs)
+{
+   Widget convdiag = (Widget) cdata;
+
+   /* it OK so create a logfile */
+   mk_log();
+   XtUnmanageChild (convdiag);
+   return;
+} 
+
+
 /* 
  * mk_log - write the logfile.  The option button string says what
  * format to write.
@@ -921,55 +1001,69 @@ void mk_log (void)
 }
 
 
-
 /*
- * Error Dialog - called from many places and passed the parent widget,
- * the error message to display and a flag that indicates the Cancel
- * button is not wanted.  Only the File Exist diag gets a Cancel btn.
+ * Error Dialog - creates an error dialog with either an OK or Exit Button.
+ * Called from many places and passed the parent widget, the error message
+ * to display and a flag that indicates if there should be an OK button 
+ * or a Cancel/Exit button.
  */
-void errorDiag (Widget w, char * emess, int flag)
+void errorDiag (Widget w, char *emess, int flag)
 {
    Widget errDiag;
-   XmString xs;
+   XmString xs_emess, xs_cancel;
 
    errDiag = XmCreateErrorDialog (w, "errDiag", NULL, 0);
-   xs = XmStringCreateLocalized(emess);
+   xs_emess = XmStringCreateLocalized(emess);
+   xs_cancel = XmStringCreateLocalized("Exit");
 
    XtVaSetValues (XtParent(errDiag),
-      XmNtitle, "Convert Error",
+      XmNtitle, "TWLOG ERROR",
+      #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM     
+      XmNiconPixmap, pixmap,
+      #endif
+      XmNmwmFunctions, MWM_FUNC_ALL | MWM_FUNC_CLOSE,
       NULL);
 
    XtVaSetValues (errDiag,
       XmNdialogStyle, XmDIALOG_PRIMARY_APPLICATION_MODAL,
-      XmNmessageString, xs,
+      XmNcancelLabelString, xs_cancel,
+      XmNmessageString, xs_emess,
       NULL);
-   XmStringFree (xs);
+   XmStringFree (xs_emess);
 
-   if (flag == NO_CANCEL)
+   XtUnmanageChild (XmMessageBoxGetChild(errDiag, XmDIALOG_HELP_BUTTON));
+   XtAddCallback (errDiag, XmNokCallback, errOkCB, (XtPointer) -1);
+
+   if (flag == CANCEL_BTN)
+   {
+      XtUnmanageChild (XmMessageBoxGetChild(errDiag, XmDIALOG_OK_BUTTON));
+      XtAddCallback (errDiag, XmNcancelCallback, errCancelCB, w);
+   }
+   else
    {
       XtUnmanageChild (XmMessageBoxGetChild(errDiag, XmDIALOG_CANCEL_BUTTON));
+      XtAddCallback (errDiag, XmNcancelCallback, errOkCB, XtParent(w));
    }
-   XtUnmanageChild (XmMessageBoxGetChild(errDiag, XmDIALOG_HELP_BUTTON));
 
-   /* Only the File Exists diag needs additional functionality for OK CB
-    * so add this callback if there is a Cancel button, since only the
-    * File Exists diag has one
-    */
-   if (flag != NO_CANCEL)
-   {
-      XtAddCallback (errDiag, XmNokCallback, errOkCB, w);
-   }
    XtManageChild (errDiag);
 }
 
 
-
 /*
  * errOkCB - used by the File Exists Dialog - cdata is wid of convert diag
  * which needs to be unmanaged now.
  */
 void errOkCB (Widget w, XtPointer cdata, XtPointer cbs)
 {
-   mk_log();
-   XtUnmanageChild (cdata);
+   /* nothing to do */
 } 
+
+
+/*
+ * errCancelCB - unmanage the shell to exit
+ */
+void errCancelCB (Widget w, XtPointer cdata, XtPointer cbs)
+{
+   shmctl (shmid, IPC_RMID, NULL);    /* close the shared memory */
+   XtUnmanageChild (cdata);
+}
