@@ -1,6 +1,6 @@
 /*
  * twlog:  A basic ham loging program using Motif
- * Copyright (C) 1997->2006 Ted Williams WA0EIR 
+ * Copyright (C) 1997->2007 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,22 +17,24 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.4 -  Oct 2006
+ * Version: 2.5 -  Dec 2007
  */
 
 /*
  * Globals for help find
  */
 
-//#ifndef TWLOG_H_INCLUDED
 #include "twlog.h"
-//#endif
 #include "twlogHelp.h"
 
 #define FIND_AGN     0
 #define THIS_SECTION 1
 #define ALL_SECTIONS 2
+#define OFFSET       5
 
+#if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM
+extern Pixmap pixmap;
+#endif
 
 char pattern[41];               /* pattern for help find */
 Widget helpTxt, findAgnPB, topicLabel;
@@ -62,6 +64,9 @@ void popupHelp (int topicNum)
 
       XtVaSetValues (XtParent (helpDiag),       /* set title bar */
          XmNtitle, "TWLOG HELP",
+         #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM
+         XmNiconPixmap, pixmap,
+         #endif
          NULL);
 
       topicLabel = XtVaCreateManagedWidget ("topicLabel", xmLabelWidgetClass,
@@ -80,27 +85,40 @@ void popupHelp (int topicNum)
          XmNrightAttachment, XmATTACH_FORM,
          NULL);
 
-      findPB =
-         XtVaCreateManagedWidget ("Find", xmPushButtonWidgetClass, pbform,
-         XmNwidth, PBWIDTH, XmNleftAttachment, XmATTACH_POSITION,
-         XmNleftPosition, 10, XmNrightAttachment, XmATTACH_POSITION,
-         XmNrightPosition, 20, 
+      findPB = XtVaCreateManagedWidget ("Find", xmPushButtonWidgetClass, pbform,
+         XmNwidth, PBWIDTH,
+         XmNtopOffset, OFFSET,
+         XmNtopAttachment, XmATTACH_FORM,
+         XmNleftAttachment, XmATTACH_POSITION,
+         XmNleftPosition, 10,
+         XmNrightAttachment, XmATTACH_NONE,
+         XmNbottomAttachment, XmATTACH_FORM,
+         XmNbottomOffset, OFFSET,
          NULL);
 
       findAgnPB = XtVaCreateManagedWidget ("Find Again",
          xmPushButtonWidgetClass, pbform,
          XmNsensitive, False,
          XmNwidth, PBWIDTH,
+         XmNtopAttachment, XmATTACH_FORM,
+         XmNtopOffset, OFFSET,
          XmNleftAttachment, XmATTACH_POSITION,
-         XmNleftPosition, 50, XmNleftOffset, -PBWIDTH / 2,
+         XmNleftPosition, 50,
+         XmNleftOffset, -PBWIDTH / 2,
+         XmNbottomAttachment, XmATTACH_FORM,
+         XmNbottomOffset, OFFSET,
          NULL);
 
       closePB = XtVaCreateManagedWidget ("Close",
          xmPushButtonWidgetClass, pbform,
          XmNwidth, PBWIDTH,
-         XmNleftAttachment, XmATTACH_POSITION,
-         XmNleftPosition, 80,
-         XmNrightAttachment, XmATTACH_POSITION, XmNrightPosition, 90,
+         XmNtopAttachment, XmATTACH_FORM,
+         XmNtopOffset, OFFSET,
+         XmNleftAttachment, XmATTACH_NONE,
+         XmNrightAttachment, XmATTACH_POSITION,
+         XmNrightPosition, 90,
+         XmNbottomAttachment, XmATTACH_FORM,
+         XmNbottomOffset, OFFSET,
          NULL);
 
       XtManageChild (pbform);
@@ -109,32 +127,23 @@ void popupHelp (int topicNum)
          XmNtopAttachment, XmATTACH_NONE,
          XmNleftAttachment, XmATTACH_FORM,
          XmNbottomAttachment, XmATTACH_WIDGET,
-         XmNbottomWidget, pbform, XmNrightAttachment, XmATTACH_FORM,
+         XmNbottomWidget, pbform,
+         XmNrightAttachment, XmATTACH_FORM,
          NULL);
 
       i = 0;
-      XtSetArg (args[i], XmNrows, 12);
-      i++;
-      XtSetArg (args[i], XmNeditMode, XmMULTI_LINE_EDIT);
-      i++;
-      XtSetArg (args[i], XmNeditable, False);
-      i++;
-      XtSetArg (args[i], XmNscrollHorizontal, False);
-      i++;
-      XtSetArg (args[i], XmNwordWrap, True);
-      i++;
-      XtSetArg (args[i], XmNtopAttachment, XmATTACH_WIDGET);
-      i++;
-      XtSetArg (args[i], XmNtopWidget, topicLabel);
-      i++;
-      XtSetArg (args[i], XmNleftAttachment, XmATTACH_FORM);
-      i++;
-      XtSetArg (args[i], XmNbottomAttachment, XmATTACH_WIDGET);
-      i++;
-      XtSetArg (args[i], XmNbottomWidget, sep);
-      i++;
-      XtSetArg (args[i], XmNrightAttachment, XmATTACH_FORM);
-      i++;
+      XtSetArg (args[i], XmNrows, 12);  i++;
+      XtSetArg (args[i], XmNeditMode, XmMULTI_LINE_EDIT);  i++;
+      XtSetArg (args[i], XmNeditable, False);  i++;
+      XtSetArg (args[i], XmNscrollHorizontal, False);  i++;
+      XtSetArg (args[i], XmNwordWrap, True);  i++;
+      XtSetArg (args[i], XmNtopAttachment, XmATTACH_WIDGET);  i++;
+      XtSetArg (args[i], XmNtopWidget, topicLabel);  i++;
+      XtSetArg (args[i], XmNleftAttachment, XmATTACH_FORM);  i++;
+      XtSetArg (args[i], XmNbottomAttachment, XmATTACH_WIDGET);  i++;
+      XtSetArg (args[i], XmNbottomWidget, sep);  i++;
+      XtSetArg (args[i], XmNbottomOffset, OFFSET); i++;
+      XtSetArg (args[i], XmNrightAttachment, XmATTACH_FORM);  i++;
 
       helpTxt = XmCreateScrolledText (helpDiag, "helpTxt", args, i);
 
@@ -201,8 +210,10 @@ void popupFindCB (Widget w, XtPointer cdata, XtPointer cbs)
 
       /* set title bar to "TWLOG HELP" */
       XtVaSetValues (XtParent (promptDiag),
-         XmNtitle, "TWLOG HELP",
-         XmNmwmFunctions, MWM_FUNC_ALL | MWM_FUNC_CLOSE,
+         XmNtitle, "TWLOG SEARCH",
+         #if MAKE_ICON && HAVE_X11_XPM_H && HAVE_LIBXPM
+         XmNiconPixmap, pixmap,
+         #endif
          NULL);
 
       /*
@@ -227,6 +238,7 @@ void popupFindCB (Widget w, XtPointer cdata, XtPointer cbs)
          XmNokLabelString, xms[0],
          XmNapplyLabelString, xms[1],
          XmNselectionLabelString, xms[2],
+         XmNdialogStyle, XmDIALOG_PRIMARY_APPLICATION_MODAL,
          NULL);
 
       for (j = 0; j < i; j++)
@@ -270,11 +282,12 @@ void doFindCB (Widget w, XtPointer cdata, XtPointer cbs)
          NULL);
       strncpy (pattern, pat, 40);
 
-      /* try removing this */
+      /* When false, it will remember the previous search pattern */
+#if 0
       XtVaSetValues (XmSelectionBoxGetChild (w, XmDIALOG_TEXT),
          XmNvalue, "",
          NULL);
-
+#endif
       /* Since we have find text, then findAgn is valid */
       XtVaSetValues (findAgnPB,
          XmNsensitive, True,
@@ -298,16 +311,21 @@ void doFindCB (Widget w, XtPointer cdata, XtPointer cbs)
       start = start + strlen (pattern);
       return;
    }
-   else                         /* didnt find it */
+   else                         /* didn't find it */
    {
       start = 0;
       /* Should we go to next section? */
-      if (flag == THIS_SECTION) /* if this section only */
+      if (flag == THIS_SECTION)   /* if this section only, we're done! */
       {
-         noMatchDiag ();
+         errorDiag (XtParent (w),
+                   "String not found", !CANCEL_BTN);
+
+         XtVaSetValues (findAgnPB,
+            XmNsensitive, False,
+            NULL);
          return;
       }
-      else
+      else  /* move to the next section and look some more */
       {
          sec++;
          if (sec >= NUM_TOPICS)
@@ -327,9 +345,13 @@ void doFindCB (Widget w, XtPointer cdata, XtPointer cbs)
             XmNvalue, helpText[sec],
             NULL);
 
-         if (sec == start_sec)
+         if (sec == start_sec)  /* if we've wrapped, then were done */
          {
-            noMatchDiag ();
+            errorDiag (XtParent (w), "String not found", !CANCEL_BTN);
+
+            XtVaSetValues (findAgnPB,
+               XmNsensitive, False,
+               NULL);
             return;
          }
          doFindCB (w, FIND_AGN, cbs);
@@ -337,45 +359,9 @@ void doFindCB (Widget w, XtPointer cdata, XtPointer cbs)
    }
 }
 
-/*
- * noMatch Dialog
- */
-void noMatchDiag ()
-{
-   XmString xs;
-   Arg args[1];
-   static Widget noMatchDiag;
-
-   if (noMatchDiag == NULL)
-   {
-      xs = XmStringCreateLocalized ("String Not Found");
-
-      XtSetArg (args[0], XmNmessageString, xs);
-      noMatchDiag = XmCreateInformationDialog (helpTxt, "noMatchDiag",
-         args, 1);
-      XmStringFree (xs);
-
-      XtUnmanageChild (XmMessageBoxGetChild (noMatchDiag,
-            XmDIALOG_HELP_BUTTON));
-      XtUnmanageChild (XmMessageBoxGetChild (noMatchDiag,
-            XmDIALOG_CANCEL_BUTTON));
-
-      XtVaSetValues (XtParent (noMatchDiag),    /* set title bar */
-         XmNtitle, "TWLOG HELP",
-         NULL);
-   }
-
-   XtVaSetValues (findAgnPB,
-      XmNsensitive, False,
-      NULL);
-
-   XtManageChild (noMatchDiag);
-   return;
-}
-
 
 /*
- * find no case
+ * find no case - finds pattern in text without regard to case
  */
 char * findNoCase (char *text, char *pattern)
 {
