@@ -1,6 +1,6 @@
 /*
  * twlog:  A basic ham loging program using Motif
- * Copyright (C) 1997->2006 Ted Williams WA0EIR 
+ * Copyright (C) 1997->2007 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.4 -  Oct 2006
+ * Version: 2.5 -  Oct 2007
  */
 
 #include "twlog.h"
@@ -62,7 +62,6 @@ void build_widgets (Widget logSH, LogRes log_res)
       XmVaCASCADEBUTTON, xs[1], 'E',
       XmVaCASCADEBUTTON, xs[2], 'H',
       NULL);
-
    for (j=0; j<i; j++)
    {
       XmStringFree (xs[j]);
@@ -95,7 +94,7 @@ void build_widgets (Widget logSH, LogRes log_res)
    fileMenu = XmVaCreateSimplePulldownMenu (menuBar, "fileMenu", 0, fileCB,
       XmVaPUSHBUTTON, xs[0], 'P', "Ctrl<Key>P", xs[1],
       XmVaPUSHBUTTON, xs[2], 'N', "Ctrl<Key>N", xs[3],
-      XmVaPUSHBUTTON, xs[4], 'v', "Ctrl<Key>v", xs[5],
+      XmVaPUSHBUTTON, xs[4], 'V', "Ctrl<Key>V", xs[5],
       XmVaSEPARATOR,
       XmVaPUSHBUTTON, xs[6], 'Q', "Ctrl<Key>Q", xs[7],
       NULL);
@@ -159,7 +158,6 @@ void build_widgets (Widget logSH, LogRes log_res)
    xs[i] = XmStringCreateLocalized ("Limits"); i++;              /* 8 */
    xs[i] = XmStringCreateLocalized ("Keyboard"); i++;            /* 9 */
 
-
    helpMenu = XmVaCreateSimplePulldownMenu (menuBar, "helpMenu", 2, helpCB,
       XmVaPUSHBUTTON, xs[0], 'A', NULL, NULL,
       XmVaPUSHBUTTON, xs[1], 'I', NULL, NULL,
@@ -183,7 +181,6 @@ void build_widgets (Widget logSH, LogRes log_res)
       XmNuserData, &col_2_wids,
       NULL);
 
-
    /*
     * Data Entry Form
     * This is the data entry form for the log.  Column 1 (lefthand side
@@ -264,21 +261,18 @@ void build_widgets (Widget logSH, LogRes log_res)
       XmNmaxLength, 9,
       NULL);
 
-   callsignTF =
-      XtVaCreateManagedWidget ("callTF", xmTextFieldWidgetClass, rc1,
+   callsignTF = XtVaCreateManagedWidget ("callTF", xmTextFieldWidgetClass, rc1,
       XmNmaxLength, 10,
       NULL);
 
    /* 
     * Band Option Menu 
     */
-
    bandMenu = buildOptionMenus (rc1, log_res.default_band, log_res.bands);
 
    /*
     * Mode Option Menu
     */
-
    modeMenu = buildOptionMenus (rc1, log_res.default_mode, log_res.modes);
 
    /*
@@ -287,7 +281,7 @@ void build_widgets (Widget logSH, LogRes log_res)
    powerMenu = buildOptionMenus (rc1, log_res.default_power, log_res.power);
 
    /*
-    * RST 1 testfield
+    * RST 1 textfield
     */
    rst1TF = XtVaCreateManagedWidget ("rst1TF", xmTextFieldWidgetClass, rc1,
       XmNmaxLength, 8,
@@ -329,12 +323,12 @@ void build_widgets (Widget logSH, LogRes log_res)
    xs[i] = XmStringCreateLocalized ("Edit Log"); i++;      /* 5 */
    xs[i] = XmStringCreateLocalized ("Ctrl-E"); i++;        /* 6 */
 
-   popup = XmVaCreateSimplePopupMenu (form1, "clrRx", editCB,
+   popup = XmVaCreateSimplePopupMenu (form1, "popup", editCB,
       XmVaTITLE, xs[0],
       XmVaSEPARATOR,
-      XmVaPUSHBUTTON, xs[1], 'C', "Ctrl<Key>c", xs[2],
+      XmVaPUSHBUTTON, xs[1], 'A', "Ctrl<Key>a", xs[2],
       XmVaPUSHBUTTON, xs[3], 'C', "Ctrl<Key>c", xs[4],
-      XmVaPUSHBUTTON, xs[5], 'C', "Ctrl<Key>c", xs[6],
+      XmVaPUSHBUTTON, xs[5], 'E', "Ctrl<Key>e", xs[6],
       NULL);
 
    for (j=0; j<i; j++)
@@ -346,12 +340,12 @@ void build_widgets (Widget logSH, LogRes log_res)
       XmNtearOffModel, XmTEAR_OFF_ENABLED, XmNuserData, &col_2_wids,
       NULL);
 
-/*
- * Initialize argument structs
- * These are passed to some callbacks
- * Note: The notesTF is the last element in the array, but
- * appears as the next to the last widget in the rowColumn.
- */
+   /*
+    * Initialize argument structs
+    * These are passed to some callbacks
+    * Note: The notesTF is the last element in the array, but
+    * appears as the next to the last widget in the rowColumn.
+    */
    dateCdata.TF1 = dateTF;
    dateCdata.TF2 = NULL;
    dateCdata.next = startPB;
@@ -375,7 +369,6 @@ void build_widgets (Widget logSH, LogRes log_res)
    col_2_wids[8] = endTF;
    col_2_wids[9] = notesTF;
 
-
    /* Event handler for popup menu */
    XtAddEventHandler (form1, ButtonPressMask, False, popupHandler,
       (XtPointer) popup);
@@ -448,7 +441,7 @@ void build_widgets (Widget logSH, LogRes log_res)
    XtAddCallback (callsignTF, XmNlosingFocusCallback, callsignCB, NULL);
 
    /*
-    * traverseCB moves to next widget
+    * traverseCB moves to next widget so PB will skip over its text field
     */
    XtAddCallback (rst1TF, XmNactivateCallback, traverseCB, NULL);
    XtAddCallback (rst2TF, XmNactivateCallback, traverseCB, NULL);
@@ -494,27 +487,28 @@ void build_widgets (Widget logSH, LogRes log_res)
 
 /*
  * Build Option Menus
- * First count the number of items listed in the labelsXS
+ * First count the number of items listed in the labels
  * of the argument.  Next build the Args array to set the
  * properties for the pulldown. Then create the option menu.
  */
 
-Widget buildOptionMenus (Widget parent, int defaultBtn, XmString *labelsXS)
+Widget buildOptionMenus (Widget parent, int defaultBtn, String *labels)
 {
    int i;
    int btn_cnt = 0;
    Widget optionForm, pulldownMenu, pulldownPB, optionMenu;
    Arg args[10];
    Widget defaultWid = 0;       /* widget id of default button */
+   XmString xs;                 /* XmString for button names */
 
-   while (!XmStringEmpty (labelsXS[btn_cnt]))
+   /* count the number of labels */
+   while (labels[btn_cnt] != NULL)
    {
       btn_cnt++;
    }
 
    optionForm = XtVaCreateManagedWidget ("optionForm", xmFormWidgetClass,
       parent,
-      XmNborderWidth, 0,
       NULL);
 
    i = 0;
@@ -525,10 +519,12 @@ Widget buildOptionMenus (Widget parent, int defaultBtn, XmString *labelsXS)
 
    for (i = 0; i < btn_cnt; i++)
    {
+      xs = XmStringCreateLocalized (labels[i]);   /* convert to XmString */
       pulldownPB = XtVaCreateManagedWidget ("PulldownPB",
          xmPushButtonWidgetClass, pulldownMenu,
-         XmNlabelString, labelsXS[i],
+         XmNlabelString, xs,
          NULL);
+      XmStringFree (xs);                /* free the XmString */
 
       if (i == defaultBtn)              /* remember this wid if it is      */
       {                                 /* the default btn and use for the */
@@ -539,11 +535,12 @@ Widget buildOptionMenus (Widget parent, int defaultBtn, XmString *labelsXS)
    i = 0;
    XtSetArg (args[i], XmNsubMenuId, pulldownMenu); i++;
    XtSetArg (args[i], XmNmenuHistory, defaultWid); i++; /* default button */
-   XtSetArg (args[i], XmNtopOffset, 0); i++;
-   XtSetArg (args[i], XmNmarginHeight, 0); i++;
-   XtSetArg (args[i], XmNmarginWidth, 0); i++;
 
-   optionMenu = XmCreateOptionMenu (optionForm, "OptionMenu", args, i);
+   optionMenu = XmCreateOptionMenu (optionForm, "optionMenu", args, i);
+
+   XtVaSetValues (XmOptionButtonGadget (optionMenu),
+      XmNborderWidth, 0,
+      NULL);
 
    XtUnmanageChild (XmOptionLabelGadget (optionMenu));
 
